@@ -175,7 +175,7 @@ class Condition:
         elif self.field.complexExpression is not None:
             field_with_agg = self.field.complexExpression
 
-        if formatted_value is not None and self.direction is None:
+        if self.direction is None:
             if negation is None:
                 where_condition = (
                         field_with_agg + " " + operator + " " + str(formatted_value)
@@ -184,7 +184,7 @@ class Condition:
                 where_condition = (
                     field_with_agg + " " + negation + " " + operator + " " + str(formatted_value)
                 )
-        elif formatted_value is None and self.direction is not None:
+        elif self.direction is not None:
             if isinstance(self.direction, PeriodOperator):
                 direction = self.direction.name
             else:
@@ -510,26 +510,30 @@ class Query:
                             # if internal and original data types are not consistent each other use this pattern
                             # aggregation column (original data type, to internal data type, date_format YYYY-MM-DD ) AS Alias
                             if where_condition.field.sourceFormat is not None:
-                                formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format " + where_condition.field.sourceFormat + ") " + operator + " " + formatted_value
+                                formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + \
+                                                 ", to " + where_condition.field.internalDataType + ", format " + \
+                                                 where_condition.field.sourceFormat + ") " + operator + " " + \
+                                                 formatted_value
                             else:
-                                if formatted_value is not None:
-                                    formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + formatted_value
-                                elif formatted_value is None and where_condition.direction is not None:
+                                if where_condition.direction is None:
+                                    formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + \
+                                                     ", to " + where_condition.field.internalDataType + ") " + \
+                                                     operator + " " + formatted_value
+                                else:
                                     if isinstance(where_condition.direction, PeriodOperator):
                                         direction = where_condition.direction.name
                                     else:
                                         direction = where_condition.direction
 
-                                    if where_condition.steps is not None and where_condition.interval is not None:
-                                        formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + where_condition.interval + " " + direction + " " + where_condition.steps
-                                    elif where_condition.steps is not None and where_condition.interval is None:
-                                        formatted_cond = (
-                                                field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + direction + " " + where_condition.steps
-                                        )
-                                    elif where_condition.steps is None and where_condition.interval is not None:
-                                        formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + where_condition.interval + " " + direction
+                                    if where_condition.steps is not None:
+                                        formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + \
+                                                         ", to " + where_condition.field.internalDataType + ") " + \
+                                                         operator + " " + direction + " " + where_condition.steps + \
+                                                         " " + formatted_value
                                     else:
-                                        formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + direction
+                                        formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + \
+                                                         ", to " + where_condition.field.internalDataType + ") " + \
+                                                         operator + " " + direction + " " + formatted_value
                         elif where_condition.field.complexExpression is not None:
                             if where_condition.field.alias is not None:
                                 formatted_cond = where_condition.field.complexExpression + " AS " + where_condition.field.alias
@@ -617,7 +621,10 @@ class Query:
             spell_str += ', "group_by":['
             groupby_vec = []
             for clause in self.groupBy:
-                groupby_vec.append(clause.field.column)
+                if clause.field.alias is not None:
+                    groupby_vec.append(clause.field.alias)
+                else:
+                    groupby_vec.append(clause.field.column)
             spell_str += ", ".join(groupby_vec) + "]"
 
         if self.orderBy is not None and self.orderBy:
