@@ -10,7 +10,8 @@ if __name__ == '__main__':
     from1 = From('{{dataset.A}}')
     from2 = From('{{dataset.B}}')
     from3 = From('{{dataset.C}}')
-    condition1 = Condition(field4, "FROM", direction="NEXT", steps="{{number.A}}", interval="{{timeDimension.B}}")
+    condition1 = Condition(field4, "FROM", direction="NEXT", negate=True, steps="{{number.A}}",
+                           interval="{{timeDimension.B}}")
     condition2 = Condition(field1, "LOE", ["{{number.B}}"])
     condition3 = Condition(field2, "IN", ["{{entity.A}}"])
     condition4 = Condition(field4, "RANGE", value=["{{timePeriodStart.A}}", "{{timePeriodEnd.A}}"])
@@ -39,7 +40,7 @@ if __name__ == '__main__':
         fields=[Field(column="store_city", alias="Store City", internalDataType="STRING", sourceDataType="TEXT"),
                 Field(column="time_the_date", alias="Time", internalDataType="DATE", sourceDataType="TEXT")],
         where=[Condition(Field(column="time_the_date", aggregation="MONTH", alias="Time", internalDataType="DATE", sourceDataType="TEXT"),
-                         operator="FROM", direction="NEXT", steps="2"),
+                         operator="FROM", direction="NEXT", steps="2", value=["November", "December"]),
                Condition(Field(column="time_the_date", aggregation="MONTH", alias="Time", internalDataType="DATE",
                                sourceDataType="TEXT"),
                          operator="FROM", value=["2022"]),
@@ -50,6 +51,7 @@ if __name__ == '__main__':
                                internalDataType="NUMERIC",
                                sourceDataType="REAL"))
                ],
+        groupBy=[GroupBy(field=Field(column="time_the_date", alias="Time", internalDataType="DATE", sourceDataType="TEXT"))],
         orderBy=[Sorting(field="Store City", order=SQLSorting.DESC),
                  Sorting(field="Time", order=SQLSorting.DESC)],
         limit=8,
